---
label: TRIDESCLOUS
dockerfile: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/container/Dockerfile
wrapper: https://github.com/flatironinstitute/spikeforest/blob/master/spikeforest/spikesorters/tridesclous/tridesclous.py
notes:
website: https://github.com/tridesclous/tridesclous
source_code:
authors: Samuel Garcia and Christophe Pouzat
processor_name: Tridesclous
doi:
---
_
# TRIDESCLOUS

## Description

From the Tridesclous website: The primary goal of tridesclous is to provide a toolkit to teach good practices in spike sorting techniques.
This tools is now mature and can be used for experimental data.

## References

